@@ -4,22 +4,23 @@ from pathlib import Path
 from typing import Callable, Optional, Type
 
 import grpc
-from grpc.aio._typing import ChannelArgumentType  # noqa
 from grpc.aio import Server
+from grpc.aio._typing import ChannelArgumentType  # noqa
+from grpc_reflection.v1alpha import reflection
 from logzero import logger
 from pydantic import BaseModel
-from grpc_reflection.v1alpha import reflection
 
 from fast_grpc.middleware import ServerErrorMiddleware, ServerStreamingErrorMiddleware
 from fast_grpc.proto import ProtoBuilder
 from fast_grpc.service import (
-    Service,
-    UnaryUnaryMethod,
-    UnaryStreamMethod,
-    StreamUnaryMethod,
-    StreamStreamMethod,
     BaseService,
+    Service,
+    StreamStreamMethod,
+    StreamUnaryMethod,
+    UnaryStreamMethod,
+    UnaryUnaryMethod,
 )
+from fast_grpc.types import ProtoTag
 from fast_grpc.utils import protoc_compile
 
 
@@ -32,30 +33,33 @@ class FastGRPC(object):
     ```python
     from fast_grpc import FastGRPC
 
-    app = FastGRPC(service_name="Greeter", proto="greeter.proto")
+    app = FastGRPC(name="Greeter", proto="greeter.proto")
     ```
     """
 
     def __init__(
         self,
         *,
-        service_name: str = "FastGRPC",
+        name: str = "FastGRPC",
         proto: str = "fast_grpc.proto",
         auto_gen_proto: bool = True,
+        type_mapping: Optional[dict[type, ProtoTag]] = None,
     ):
         """
         Args:
-            service_name: default grpc service name.
+            name: default grpc service name.
             proto: grpc proto file path.
             auto_gen_proto: Whether to automatically generate proto file or not. if not, the proto file will be defined by yourself.
+            type_mapping: custom type mapping.
         """
-        self.service = Service(name=service_name, proto=proto)
-        self._services: dict[str, Service] = {f"{proto}:{service_name}": self.service}
+        self.service = Service(name=name, proto=proto)
+        self._services: dict[str, Service] = {f"{proto}:{name}": self.service}
         self._auto_gen_proto = auto_gen_proto
         self._middlewares: list[Callable] = [ServerErrorMiddleware()]
         self._server_streaming_middlewares: list[Callable] = [
             ServerStreamingErrorMiddleware()
         ]
+        self._type_mapping = type_mapping
 
     def setup(self) -> None:
         builders = {}
@@ -64,7 +68,9 @@ class FastGRPC(object):
                 continue
             path = Path(service.proto)
             if path not in builders:
-                builders[path] = ProtoBuilder(package=path.stem)
+                builders[path] = ProtoBuilder(
+                    package=path.stem, type_mapping=self._type_mapping
+                )
             builders[path].add_service(service)
         for proto, builder in builders.items():
             if self._auto_gen_proto:
@@ -177,6 +183,7 @@ class FastGRPC(object):
         host: str = "127.0.0.1",
         port: int = 50051,
         server: Optional[Server] = None,
+        reflection_enable: bool = True,
     ) -> None:
         loop = asyncio.get_event_loop()
         loop.run_until_complete(
@@ -184,6 +191,7 @@ class FastGRPC(object):
                 host=host,
                 port=port,
                 server=server,
+                reflection_enable=reflection_enable,
             )
         )
         loop.close()
@@ -193,12 +201,12 @@ class FastGRPC(object):
         host: str = "127.0.0.1",
         port: int = 50051,
         server: Optional[Server] = None,
-        enable_reflection: bool = True,
+        reflection_enable: bool = True,
     ) -> None:
         server = grpc.aio.server() if not server else server
         server.add_insecure_port(f"{host}:{port}")
         self.add_to_server(server)
-        if enable_reflection:
+        if reflection_enable:
             self.enable_server_reflection(server)
         await server.start()
         logger.info(f"Running grpc on {host}:{port}")
