@@ -3,22 +3,22 @@ import datetime
 import typing
 from enum import IntEnum
 from pathlib import Path
-from typing import Type, Sequence, Any, Annotated
+from typing import Annotated, Any, Sequence, Type
 
 import grpc
+from jinja2 import Template
 from pydantic import BaseModel, Field
 from typing_extensions import get_args, get_origin
-from jinja2 import Template
-from google.protobuf.descriptor import (
-    ServiceDescriptor,
-    Descriptor,
-    FieldDescriptor,
-    EnumDescriptor,
-)
 
-from fast_grpc.service import Service, MethodMode
-from fast_grpc.types import Empty, ProtoTag, PYTHON_TO_PROTOBUF_TYPES
-from fast_grpc.utils import protoc_compile, camel_to_snake
+from fast_grpc.service import MethodMode, Service
+from fast_grpc.types import PYTHON_TO_PROTOBUF_TYPES, Empty, ProtoTag
+from fast_grpc.utils import camel_to_snake, protoc_compile
+from google.protobuf.descriptor import (
+    Descriptor,
+    EnumDescriptor,
+    FieldDescriptor,
+    ServiceDescriptor,
+)
 
 _base_types = {
     bytes: "bytes",
@@ -192,10 +192,13 @@ def generate_type_name(type_: type) -> str:
 
 
 class ProtoBuilder:
-    def __init__(self, package: str):
+    def __init__(self, package: str, type_mapping=None):
         self._proto_define = ProtoDefine(
             package=package, services=[], messages={}, enums={}
         )
+        self._type_mapping = PYTHON_TO_PROTOBUF_TYPES
+        if type_mapping:
+            self._type_mapping.update(type_mapping)
 
     def add_service(self, service: Service):
         srv = ProtoService(name=service.name, methods=[])
@@ -253,8 +256,8 @@ class ProtoBuilder:
     def _get_type_name(self, type_: Any) -> str:
         if isinstance(type_, str):
             return type_
-        if type_ in PYTHON_TO_PROTOBUF_TYPES:
-            tag = PYTHON_TO_PROTOBUF_TYPES[type_]
+        if type_ in self._type_mapping:
+            tag = self._type_mapping[type_]
             self._proto_define.dependencies.add(tag.package)
             return tag.name
         origin = get_origin(type_)
@@ -290,8 +293,8 @@ class ClientBuilder:
         )
         self.pb2 = grpc.protos(self._proto_define.package)
         self._proto_package = self.pb2.DESCRIPTOR.package
-        self._processed_messages = []
-        self._processing_stack = set()
+        self._processed_messages: list[Any] = []
+        self._processing_stack: set[Any] = set()
 
     def get_proto(self):
         for service in self.pb2.DESCRIPTOR.services_by_name.values():
